/*
** Module   : InnerLines.java
** Abstract : Groups widgets that have the INNER-LINES attribute.
**
** Copyright (c) 2014-2015, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- ----------------------------Description--------------------------------------
** 001 GES 20141120 Created initial version.
** 002 IAS 20150612 Added setInitialInnerLines method.
*/

package com.goldencode.p2j.ui;

import com.goldencode.p2j.util.*;

/**
 * Groups widgets that have the INNER-LINES attribute.
 */
public interface InnerLines
{
   /**
    * Gets the value of the INNER-LINES attribute which defines the number of text lines
    * in the widget.
    * 
    * @return   The number of lines of text.
    */
   @LegacyAttribute(name = "INNER-LINES")
   public integer getInnerLines();

   /**
    * Sets the value of the INNER-LINES attribute which defines the number of text lines
    * in the widget.
    * 
    * @param    lines
    *           The new number of lines.
    */
   @LegacyAttribute(name = "INNER-LINES", setter = true)
   public void setInnerLines(double lines);

   /**
    * Sets the value of the INNER-LINES attribute which defines the number of text lines
    * in the widget. For the INNER-LINES clause in the VIEW-AS phrase
    * 
    * @param    lines
    *           The new number of lines.
    */
   public void setInitialInnerLines(double lines);

   /**
    * Sets the value of the INNER-LINES attribute which defines the number of text lines
    * in the widget.
    * 
    * @param    lines
    *           The new number of lines.
    */
   @LegacyAttribute(name = "INNER-LINES", setter = true)
   public void setInnerLines(NumberType lines);
}
